==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-sysstat/translations/sysstat_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>LXQtSysStatColours</name>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="14"/>
        <source>System Statistics Colors</source>
        <translation>Colors de les estadístiques del sistema</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="24"/>
        <source>Graph</source>
        <translation>Gràfica</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="30"/>
        <source>&amp;Grid</source>
        <translation>&amp;Quadrícula</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="40"/>
        <location filename="../lxqtsysstatcolours.ui" line="57"/>
        <location filename="../lxqtsysstatcolours.ui" line="73"/>
        <location filename="../lxqtsysstatcolours.ui" line="90"/>
        <location filename="../lxqtsysstatcolours.ui" line="117"/>
        <location filename="../lxqtsysstatcolours.ui" line="144"/>
        <location filename="../lxqtsysstatcolours.ui" line="151"/>
        <location filename="../lxqtsysstatcolours.ui" line="178"/>
        <location filename="../lxqtsysstatcolours.ui" line="205"/>
        <location filename="../lxqtsysstatcolours.ui" line="232"/>
        <location filename="../lxqtsysstatcolours.ui" line="239"/>
        <location filename="../lxqtsysstatcolours.ui" line="265"/>
        <location filename="../lxqtsysstatcolours.ui" line="282"/>
        <source>Change ...</source>
        <translation>Canvia...</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="47"/>
        <source>T&amp;itle</source>
        <translation>Tít&amp;ol</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="67"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="80"/>
        <source>&amp;Nice</source>
        <translation>&amp;Nice</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="97"/>
        <source>Ot&amp;her</source>
        <translation>Alt&amp;res</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="107"/>
        <source>&amp;Frequency</source>
        <translation>&amp;Freqüència</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="124"/>
        <source>S&amp;ystem</source>
        <translation>S&amp;istema</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="134"/>
        <source>&amp;User</source>
        <translation>&amp;Usuari</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="172"/>
        <source>Memory</source>
        <translation>Memòria</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="185"/>
        <source>Cache&amp;d</source>
        <translation>Ca&amp;u</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="195"/>
        <source>S&amp;wap</source>
        <translation>Intercan&amp;vi</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="212"/>
        <source>&amp;Applications</source>
        <translation>&amp;Aplicacions</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="222"/>
        <source>&amp;Buffers</source>
        <translation>&amp;Búfers</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="249"/>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="255"/>
        <source>&amp;Received</source>
        <translation>&amp;Recepció</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="272"/>
        <source>&amp;Transmitted</source>
        <translation>&amp;Transmissió</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatConfiguration</name>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="14"/>
        <source>System Statistics Settings</source>
        <translation>Ajusts de les estadístiques del sistema</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="22"/>
        <source>Graph</source>
        <translation>Gràfica</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="34"/>
        <source>&amp;Minimal size</source>
        <translation>&amp;Mida mínima</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="44"/>
        <source>Update &amp;interval</source>
        <translation>&amp;Interval d&apos;actualització</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="54"/>
        <source>&amp;Title</source>
        <translation>&amp;Títol</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="64"/>
        <source>&amp;Grid lines</source>
        <translation>Línies de &amp;quadrícula</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="80"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Minimal width if the panel is horizontal.&lt;/p&gt;&lt;p&gt;Minimal height is the panel is vertical.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;L&apos;amplada mínima si el tauler és horitzontal.&lt;/p&gt;&lt;p&gt;L&apos;alçada mínima si el tauler és vertical.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="83"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="99"/>
        <source> s</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="124"/>
        <source>Data</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="149"/>
        <source>Use &amp;frequency</source>
        <translation>Utilitza la &amp;freqüència</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="207"/>
        <source>Ma&amp;ximum</source>
        <translation>Mà&amp;xim</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="222"/>
        <source>XXX KBs</source>
        <translation>XXX KBs</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="241"/>
        <source>Lo&amp;garithmic scale</source>
        <translation>Escala lo&amp;garítmica</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="248"/>
        <source> steps</source>
        <translation> passos</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="286"/>
        <source>&amp;Source</source>
        <translation>Orig&amp;en</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="296"/>
        <source>T&amp;ype</source>
        <translation>T&amp;ipus</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="312"/>
        <source>Colours</source>
        <translation>Colors</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="327"/>
        <source>Use t&amp;heme colours</source>
        <translation>Utilitza els colors del te&amp;ma</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="337"/>
        <source>Use c&amp;ustom colours</source>
        <translation>&amp;Utilitza els colors personalitzats</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="344"/>
        <source>Custom colour ...</source>
        <translation>Colors personalitzats...</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="41"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="42"/>
        <source>Memory</source>
        <translation>Memòria</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="43"/>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="54"/>
        <source>cpu</source>
        <translation>cpu</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="55"/>
        <source>cpu0</source>
        <translation>cpu0</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="56"/>
        <source>cpu1</source>
        <translation>cpu1</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="57"/>
        <source>cpu2</source>
        <translation>cpu2</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="58"/>
        <source>cpu3</source>
        <translation>cpu3</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="59"/>
        <source>cpu4</source>
        <translation>cpu4</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="60"/>
        <source>cpu5</source>
        <translation>cpu5</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="61"/>
        <source>cpu6</source>
        <translation>cpu6</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="62"/>
        <source>cpu7</source>
        <translation>cpu7</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="63"/>
        <source>cpu8</source>
        <translation>cpu8</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="64"/>
        <source>cpu9</source>
        <translation>cpu9</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="65"/>
        <source>cpu10</source>
        <translation>cpu10</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="66"/>
        <source>cpu11</source>
        <translation>cpu11</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="67"/>
        <source>cpu12</source>
        <translation>cpu12</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="68"/>
        <source>cpu13</source>
        <translation>cpu13</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="69"/>
        <source>cpu14</source>
        <translation>cpu14</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="70"/>
        <source>cpu15</source>
        <translation>cpu15</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="71"/>
        <source>cpu16</source>
        <translation>cpu16</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="72"/>
        <source>cpu17</source>
        <translation>cpu17</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="73"/>
        <source>cpu18</source>
        <translation>cpu18</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="74"/>
        <source>cpu19</source>
        <translation>cpu19</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="75"/>
        <source>cpu20</source>
        <translation>cpu20</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="76"/>
        <source>cpu21</source>
        <translation>cpu21</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="77"/>
        <source>cpu22</source>
        <translation>cpu22</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="78"/>
        <source>cpu23</source>
        <translation>cpu23</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="79"/>
        <source>memory</source>
        <translation>memòria</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="80"/>
        <source>swap</source>
        <translation>intercanvi</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatContent</name>
    <message>
        <location filename="../lxqtsysstat.cpp" line="397"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: %5%</source>
        <comment>CPU tooltip information</comment>
        <translation>sistema: %1%&lt;br&gt;usuari: %2%&lt;br&gt;nice: %3%&lt;br&gt;altres: %4%&lt;br&gt;freq.: %5%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="446"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: n/a</source>
        <comment>CPU tooltip information</comment>
        <translation>sistema: %1%&lt;br&gt;usuari: %2%&lt;br&gt;nice: %3%&lt;br&gt;altres: %4%&lt;br&gt;freq: n/a</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="488"/>
        <source>apps: %1%&lt;br&gt;buffers: %2%&lt;br&gt;cached: %3%</source>
        <comment>Memory tooltip information</comment>
        <translation>apps: %1%&lt;br&gt;búfers: %2%&lt;br&gt;cau: %3%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="522"/>
        <source>used: %1%</source>
        <comment>Swap tooltip information</comment>
        <translation>utilitzat: %1%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="552"/>
        <source>min: %1%&lt;br&gt;max: %2%</source>
        <comment>Network tooltip information</comment>
        <translation>mín.: %1%&lt;br&gt;màx.: %2%</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-sysstat/translations/sysstat_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>LXQtSysStatColours</name>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="14"/>
        <source>System Statistics Colors</source>
        <translation>Colors de les estadístiques del sistema</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="24"/>
        <source>Graph</source>
        <translation>Gràfica</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="30"/>
        <source>&amp;Grid</source>
        <translation>&amp;Quadrícula</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="40"/>
        <location filename="../lxqtsysstatcolours.ui" line="57"/>
        <location filename="../lxqtsysstatcolours.ui" line="73"/>
        <location filename="../lxqtsysstatcolours.ui" line="90"/>
        <location filename="../lxqtsysstatcolours.ui" line="117"/>
        <location filename="../lxqtsysstatcolours.ui" line="144"/>
        <location filename="../lxqtsysstatcolours.ui" line="151"/>
        <location filename="../lxqtsysstatcolours.ui" line="178"/>
        <location filename="../lxqtsysstatcolours.ui" line="205"/>
        <location filename="../lxqtsysstatcolours.ui" line="232"/>
        <location filename="../lxqtsysstatcolours.ui" line="239"/>
        <location filename="../lxqtsysstatcolours.ui" line="265"/>
        <location filename="../lxqtsysstatcolours.ui" line="282"/>
        <source>Change ...</source>
        <translation>Canvia...</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="47"/>
        <source>T&amp;itle</source>
        <translation>Tít&amp;ol</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="67"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="80"/>
        <source>&amp;Nice</source>
        <translation>&amp;Nice</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="97"/>
        <source>Ot&amp;her</source>
        <translation>Alt&amp;res</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="107"/>
        <source>&amp;Frequency</source>
        <translation>&amp;Freqüència</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="124"/>
        <source>S&amp;ystem</source>
        <translation>S&amp;istema</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="134"/>
        <source>&amp;User</source>
        <translation>&amp;Usuari</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="172"/>
        <source>Memory</source>
        <translation>Memòria</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="185"/>
        <source>Cache&amp;d</source>
        <translation>Ca&amp;u</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="195"/>
        <source>S&amp;wap</source>
        <translation>Intercan&amp;vi</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="212"/>
        <source>&amp;Applications</source>
        <translation>&amp;Aplicacions</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="222"/>
        <source>&amp;Buffers</source>
        <translation>&amp;Búfers</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="249"/>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="255"/>
        <source>&amp;Received</source>
        <translation>&amp;Recepció</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="272"/>
        <source>&amp;Transmitted</source>
        <translation>&amp;Transmissió</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatConfiguration</name>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="14"/>
        <source>System Statistics Settings</source>
        <translation>Ajusts de les estadístiques del sistema</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="22"/>
        <source>Graph</source>
        <translation>Gràfica</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="34"/>
        <source>&amp;Minimal size</source>
        <translation>&amp;Mida mínima</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="44"/>
        <source>Update &amp;interval</source>
        <translation>&amp;Interval d&apos;actualització</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="54"/>
        <source>&amp;Title</source>
        <translation>&amp;Títol</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="64"/>
        <source>&amp;Grid lines</source>
        <translation>Línies de &amp;quadrícula</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="80"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Minimal width if the panel is horizontal.&lt;/p&gt;&lt;p&gt;Minimal height if the panel is vertical.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="83"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="99"/>
        <source> s</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="124"/>
        <source>Data</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="149"/>
        <source>Use &amp;frequency</source>
        <translation>Utilitza la &amp;freqüència</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="207"/>
        <source>Ma&amp;ximum</source>
        <translation>Mà&amp;xim</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="222"/>
        <source>XXX KBs</source>
        <translation>XXX KBs</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="241"/>
        <source>Lo&amp;garithmic scale</source>
        <translation>Escala lo&amp;garítmica</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="248"/>
        <source> steps</source>
        <translation> passos</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="286"/>
        <source>&amp;Source</source>
        <translation>Orig&amp;en</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="296"/>
        <source>T&amp;ype</source>
        <translation>T&amp;ipus</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="312"/>
        <source>Colours</source>
        <translation>Colors</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="327"/>
        <source>Use t&amp;heme colours</source>
        <translation>Utilitza els colors del te&amp;ma</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="337"/>
        <source>Use c&amp;ustom colours</source>
        <translation>&amp;Utilitza els colors personalitzats</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="344"/>
        <source>Custom colour ...</source>
        <translation>Colors personalitzats...</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="41"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="42"/>
        <source>Memory</source>
        <translation>Memòria</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="43"/>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="54"/>
        <source>cpu</source>
        <translation>cpu</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="55"/>
        <source>cpu0</source>
        <translation>cpu0</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="56"/>
        <source>cpu1</source>
        <translation>cpu1</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="57"/>
        <source>cpu2</source>
        <translation>cpu2</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="58"/>
        <source>cpu3</source>
        <translation>cpu3</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="59"/>
        <source>cpu4</source>
        <translation>cpu4</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="60"/>
        <source>cpu5</source>
        <translation>cpu5</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="61"/>
        <source>cpu6</source>
        <translation>cpu6</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="62"/>
        <source>cpu7</source>
        <translation>cpu7</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="63"/>
        <source>cpu8</source>
        <translation>cpu8</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="64"/>
        <source>cpu9</source>
        <translation>cpu9</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="65"/>
        <source>cpu10</source>
        <translation>cpu10</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="66"/>
        <source>cpu11</source>
        <translation>cpu11</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="67"/>
        <source>cpu12</source>
        <translation>cpu12</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="68"/>
        <source>cpu13</source>
        <translation>cpu13</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="69"/>
        <source>cpu14</source>
        <translation>cpu14</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="70"/>
        <source>cpu15</source>
        <translation>cpu15</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="71"/>
        <source>cpu16</source>
        <translation>cpu16</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="72"/>
        <source>cpu17</source>
        <translation>cpu17</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="73"/>
        <source>cpu18</source>
        <translation>cpu18</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="74"/>
        <source>cpu19</source>
        <translation>cpu19</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="75"/>
        <source>cpu20</source>
        <translation>cpu20</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="76"/>
        <source>cpu21</source>
        <translation>cpu21</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="77"/>
        <source>cpu22</source>
        <translation>cpu22</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="78"/>
        <source>cpu23</source>
        <translation>cpu23</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="79"/>
        <source>memory</source>
        <translation>memòria</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="80"/>
        <source>swap</source>
        <translation>intercanvi</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatContent</name>
    <message>
        <location filename="../lxqtsysstat.cpp" line="397"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: %5%</source>
        <comment>CPU tooltip information</comment>
        <translation>sistema: %1%&lt;br&gt;usuari: %2%&lt;br&gt;nice: %3%&lt;br&gt;altres: %4%&lt;br&gt;freq.: %5%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="446"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: n/a</source>
        <comment>CPU tooltip information</comment>
        <translation>sistema: %1%&lt;br&gt;usuari: %2%&lt;br&gt;nice: %3%&lt;br&gt;altres: %4%&lt;br&gt;freq: n/a</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="488"/>
        <source>apps: %1%&lt;br&gt;buffers: %2%&lt;br&gt;cached: %3%</source>
        <comment>Memory tooltip information</comment>
        <translation>apps: %1%&lt;br&gt;búfers: %2%&lt;br&gt;cau: %3%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="522"/>
        <source>used: %1%</source>
        <comment>Swap tooltip information</comment>
        <translation>utilitzat: %1%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="552"/>
        <source>min: %1%&lt;br&gt;max: %2%</source>
        <comment>Network tooltip information</comment>
        <translation>mín.: %1%&lt;br&gt;màx.: %2%</translation>
    </message>
</context>
</TS>
